Contact
=======
This page provides information about how to ask a question, or post an issue.

Developing-team
---------------
Currently, the team consists of three active developers:

.. table::
   :widths: 2, 7

   +------------+----------------------------------------------------------------------+
   | |Picture1| | | **Patrick Vogel**                                                  |
   |            | |                                                                    |
   |            | | Project Leader                                                     |
   |            | |                                                                    |
   |            | | **E-mail:** `patrickvogel@live.nl <mailto:patrickvogel@live.nl>`_. |
   +------------+----------------------------------------------------------------------+
   | |Picture2| | | **Bogdan Petre**                                                   |
   |            | |                                                                    |
   |            | | Core Developer                                                     |
   +------------+----------------------------------------------------------------------+
   | |Picture3| | | **Thijs Klooster**                                                 |
   |            | |                                                                    |
   |            | | Test Monitor Specialist                                            |
   +------------+----------------------------------------------------------------------+

.. |Picture1| image:: https://avatars2.githubusercontent.com/u/17162650?s=460&v=4
			  ..:width: 100px

.. |Picture2| image:: https://avatars2.githubusercontent.com/u/7281856?s=400&v=4
			  ..:width: 100px

.. |Picture3| image:: https://avatars3.githubusercontent.com/u/17165311?s=400&v=4
			  ..:width: 100px


Found a bug?
------------
Post an `issue on Github <https://github.com/flask-dashboard/Flask-MonitoringDashboard/issues>`_.
You can use the template below for the right formatting:

.. topic:: Issue Template

	- Expected Behavior

	  *Tell us what should happen*

	- Current Behavior

	  *Tell us what happens instead of the expected behavior*

	- Possible Solution

	  *Not obligatory, but suggest a fix/reason for the bug*

	- Steps to Reproduce

	  *Provide a link to a live example, or an unambiguous set of steps to reproduce this bug. Include code to reproduce, if relevant*

	  1.

	  2.
	  
	  3.
	  
	  4.

	- Context (Environment)
	
	  *How has this issue affected you? What are you trying to accomplish? 
	  Providing context helps us come up with a solution that is most useful in the real world*

	- Detailed Description
	
	  *Provide a detailed description of the change or addition you are proposing*

	- Possible Implementation
	 
	  *Not obligatory, but suggest an idea for implementing addition or change*

